==> OSCA.workflows_1.16.0.tar.gz: OSCA.workflows/inst/doc/book/muraro-pancreas.md <==
# Muraro human pancreas (CEL-seq)

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the @muraro2016singlecell CEL-seq dataset,
consisting of human pancreas cells from various donors.

## Data loading


``` r
library(scRNAseq)
sce.muraro <- MuraroPancreasData()
```

Converting back to Ensembl identifiers.


``` r
library(AnnotationHub)
edb <- AnnotationHub()[["AH73881"]]
gene.symb <- sub("__chr.*$", "", rownames(sce.muraro))
gene.ids <- mapIds(edb, keys=gene.symb, 
    keytype="SYMBOL", column="GENEID")

# Removing duplicated genes or genes without Ensembl IDs.
keep <- !is.na(gene.ids) & !duplicated(gene.ids)
sce.muraro <- sce.muraro[keep,]
rownames(sce.muraro) <- gene.ids[keep]
```

## Quality control


``` r
unfiltered <- sce.muraro
```

This dataset lacks mitochondrial genes so we will do without.
For the one batch that seems to have a high proportion of low-quality cells, we compute an appropriate filter threshold using a shared median and MAD from the other batches (Figure \@ref(fig:unref-muraro-qc-dist)).


``` r
library(scater)
stats <- perCellQCMetrics(sce.muraro)
qc <- quickPerCellQC(stats, percent_subsets="altexps_ERCC_percent",
    batch=sce.muraro$donor, subset=sce.muraro$donor!="D28")
sce.muraro <- sce.muraro[,!qc$discard]
```


``` r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, x="donor", y="sum", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, x="donor", y="detected", colour_by="discard") +
        scale_y_log10() + ggtitle("Detected features"),
    plotColData(unfiltered, x="donor", y="altexps_ERCC_percent",
        colour_by="discard") + ggtitle("ERCC percent"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-qc-dist-1.png" alt="Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-muraro-qc-dist)Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>

We have a look at the causes of removal:


``` r
colSums(as.matrix(qc))
```

```
##              low_lib_size            low_n_features high_altexps_ERCC_percent 
##                       663                       700                       738 
##                   discard 
##                       773
```

## Normalization


``` r
library(scran)
set.seed(1000)
clusters <- quickCluster(sce.muraro)
sce.muraro <- computeSumFactors(sce.muraro, clusters=clusters)
sce.muraro <- logNormCounts(sce.muraro)
```


``` r
summary(sizeFactors(sce.muraro))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##  0.0878  0.5411  0.8208  1.0000  1.2108 13.9869
```


``` r
plot(librarySizeFactors(sce.muraro), sizeFactors(sce.muraro), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset." width="672" />
<p class="caption">(\#fig:unref-muraro-norm)Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset.</p>
</div>

## Variance modelling

We block on a combined plate and donor factor.


``` r
block <- paste0(sce.muraro$plate, "_", sce.muraro$donor)
dec.muraro <- modelGeneVarWithSpikes(sce.muraro, "ERCC", block=block)
top.muraro <- getTopHVGs(dec.muraro, prop=0.1)
```


``` r
par(mfrow=c(8,4))
blocked.stats <- dec.muraro$per.block
for (i in colnames(blocked.stats)) {
    current <- blocked.stats[[i]]
    plot(current$mean, current$total, main=i, pch=16, cex=0.5,
        xlab="Mean of log-expression", ylab="Variance of log-expression")
    curfit <- metadata(current)
    points(curfit$mean, curfit$var, col="red", pch=16)
    curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-variance-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor." width="672" />
<p class="caption">(\#fig:unref-muraro-variance)Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor.</p>
</div>

## Data integration


``` r
library(batchelor)
set.seed(1001010)
merged.muraro <- fastMNN(sce.muraro, subset.row=top.muraro, 
    batch=sce.muraro$donor)
```

We use the proportion of variance lost as a diagnostic measure:


``` r
metadata(merged.muraro)$merge.info$lost.var
```

```
##           D28      D29      D30     D31
## [1,] 0.060847 0.024121 0.000000 0.00000
## [2,] 0.002646 0.003018 0.062421 0.00000
## [3,] 0.003449 0.002641 0.002598 0.08162
```

## Dimensionality reduction


``` r
set.seed(100111)
merged.muraro <- runTSNE(merged.muraro, dimred="corrected")
```

## Clustering


``` r
snn.gr <- buildSNNGraph(merged.muraro, use.dimred="corrected")
colLabels(merged.muraro) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


``` r
tab <- table(Cluster=colLabels(merged.muraro), CellType=sce.muraro$label)
library(pheatmap)
pheatmap(log10(tab+10), color=viridis::viridis(100))
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-seger-heat-1.png" alt="Heatmap of the frequency of cells from each cell type label in each cluster." width="672" />
<p class="caption">(\#fig:unref-seger-heat)Heatmap of the frequency of cells from each cell type label in each cluster.</p>
</div>


``` r
table(Cluster=colLabels(merged.muraro), Donor=merged.muraro$batch)
```

```
##        Donor
## Cluster D28 D29 D30 D31
##      1  104   6  57 112
##      2   59  21  77  97
##      3   12  75  64  43
##      4   28 149 126 120
##      5   87 261 277 214
##      6   21   7  54  26
##      7    1   6   6  37
##      8    6   6   5   2
##      9   11  68   5  30
##      10   4   2   5   8
```


``` r
gridExtra::grid.arrange(
    plotTSNE(merged.muraro, colour_by="label"),
    plotTSNE(merged.muraro, colour_by="batch"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-tsne-1.png" alt="Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right)." width="672" />
<p class="caption">(\#fig:unref-muraro-tsne)Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right).</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.5.0 RC (2025-04-04 r88126)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 24.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.21-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.12.0  LAPACK version 3.12.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] pheatmap_1.0.12             batchelor_1.24.0           
 [3] scran_1.36.0                scater_1.36.0              
 [5] ggplot2_3.5.2               scuttle_1.18.0             
 [7] ensembldb_2.32.0            AnnotationFilter_1.32.0    
 [9] GenomicFeatures_1.60.0      AnnotationDbi_1.70.0       
[11] AnnotationHub_3.16.0        BiocFileCache_2.16.0       
[13] dbplyr_2.5.0                scRNAseq_2.21.1            
[15] SingleCellExperiment_1.30.0 SummarizedExperiment_1.38.0
[17] Biobase_2.68.0              GenomicRanges_1.60.0       
[19] GenomeInfoDb_1.44.0         IRanges_2.42.0             
[21] S4Vectors_0.46.0            BiocGenerics_0.54.0        
[23] generics_0.1.3              MatrixGenerics_1.20.0      
[25] matrixStats_1.5.0           BiocStyle_2.36.0           
[27] rebook_1.18.0              

loaded via a namespace (and not attached):
  [1] RColorBrewer_1.1-3        jsonlite_2.0.0           
  [3] CodeDepends_0.6.6         magrittr_2.0.3           
  [5] ggbeeswarm_0.7.2          gypsum_1.4.0             
  [7] farver_2.1.2              rmarkdown_2.29           
  [9] BiocIO_1.18.0             vctrs_0.6.5              
 [11] DelayedMatrixStats_1.30.0 memoise_2.0.1            
 [13] Rsamtools_2.24.0          RCurl_1.98-1.17          
 [15] htmltools_0.5.8.1         S4Arrays_1.8.0           
 [17] curl_6.2.2                BiocNeighbors_2.2.0      
 [19] Rhdf5lib_1.30.0           SparseArray_1.8.0        
 [21] rhdf5_2.52.0              sass_0.4.10              
 [23] alabaster.base_1.8.0      bslib_0.9.0              
 [25] alabaster.sce_1.8.0       httr2_1.1.2              
 [27] cachem_1.1.0              ResidualMatrix_1.18.0    
 [29] GenomicAlignments_1.44.0  igraph_2.1.4             
 [31] mime_0.13                 lifecycle_1.0.4          
 [33] pkgconfig_2.0.3           rsvd_1.0.5               
 [35] Matrix_1.7-3              R6_2.6.1                 
 [37] fastmap_1.2.0             GenomeInfoDbData_1.2.14  
 [39] digest_0.6.37             colorspace_2.1-1         
 [41] dqrng_0.4.1               irlba_2.3.5.1            
 [43] ExperimentHub_2.16.0      RSQLite_2.3.9            
 [45] beachmat_2.24.0           labeling_0.4.3           
 [47] filelock_1.0.3            httr_1.4.7               
 [49] abind_1.4-8               compiler_4.5.0           
 [51] bit64_4.6.0-1             withr_3.0.2              
 [53] BiocParallel_1.42.0       viridis_0.6.5            
 [55] DBI_1.2.3                 HDF5Array_1.36.0         
 [57] alabaster.ranges_1.8.0    alabaster.schemas_1.8.0  
 [59] rappdirs_0.3.3            DelayedArray_0.34.0      
 [61] bluster_1.18.0            rjson_0.2.23             
 [63] tools_4.5.0               vipor_0.4.7              
 [65] beeswarm_0.4.0            glue_1.8.0               
 [67] h5mread_1.0.0             restfulr_0.0.15          
 [69] rhdf5filters_1.20.0       grid_4.5.0               
 [71] Rtsne_0.17                cluster_2.1.8.1          
 [73] gtable_0.3.6              metapod_1.16.0           
 [75] BiocSingular_1.24.0       ScaledMatrix_1.16.0      
 [77] XVector_0.48.0            ggrepel_0.9.6            
 [79] BiocVersion_3.21.1        pillar_1.10.2            
 [81] limma_3.64.0              dplyr_1.1.4              
 [83] lattice_0.22-7            rtracklayer_1.68.0       
 [85] bit_4.6.0                 tidyselect_1.2.1         
 [87] locfit_1.5-9.12           Biostrings_2.76.0        
 [89] knitr_1.50                gridExtra_2.3            
 [91] bookdown_0.43             ProtGenerics_1.40.0      
 [93] edgeR_4.6.0               xfun_0.52                
 [95] statmod_1.5.0             UCSC.utils_1.4.0         
 [97] lazyeval_0.2.2            yaml_2.3.10              
 [99] evaluate_1.0.3            codetools_0.2-20         
[101] tibble_3.2.1              alabaster.matrix_1.8.0   
[103] BiocManager_1.30.25       graph_1.86.0             
[105] cli_3.6.4                 munsell_0.5.1            
[107] jquerylib_0.1.4           Rcpp_1.0.14              
[109] dir.expiry_1.16.0         png_0.1-8                
[111] XML_3.99-0.18             parallel_4.5.0           
[113] blob_1.2.4                sparseMatrixStats_1.20.0 
[115] bitops_1.0-9              viridisLite_0.4.2        
[117] alabaster.se_1.8.0        scales_1.3.0             
[119] purrr_1.0.4               crayon_1.5.3             
[121] rlang_1.1.6               cowplot_1.1.3            
[123] KEGGREST_1.48.0          
```
</div>

==> OSCA.workflows_1.17.0.tar.gz: OSCA.workflows/inst/doc/book/muraro-pancreas.md <==
# Muraro human pancreas (CEL-seq)

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the @muraro2016singlecell CEL-seq dataset,
consisting of human pancreas cells from various donors.

## Data loading


``` r
library(scRNAseq)
sce.muraro <- MuraroPancreasData()
```

Converting back to Ensembl identifiers.


``` r
library(AnnotationHub)
edb <- AnnotationHub()[["AH73881"]]
gene.symb <- sub("__chr.*$", "", rownames(sce.muraro))
gene.ids <- mapIds(edb, keys=gene.symb, 
    keytype="SYMBOL", column="GENEID")

# Removing duplicated genes or genes without Ensembl IDs.
keep <- !is.na(gene.ids) & !duplicated(gene.ids)
sce.muraro <- sce.muraro[keep,]
rownames(sce.muraro) <- gene.ids[keep]
```

## Quality control


``` r
unfiltered <- sce.muraro
```

This dataset lacks mitochondrial genes so we will do without.
For the one batch that seems to have a high proportion of low-quality cells, we compute an appropriate filter threshold using a shared median and MAD from the other batches (Figure \@ref(fig:unref-muraro-qc-dist)).


``` r
library(scater)
stats <- perCellQCMetrics(sce.muraro)
qc <- quickPerCellQC(stats, percent_subsets="altexps_ERCC_percent",
    batch=sce.muraro$donor, subset=sce.muraro$donor!="D28")
sce.muraro <- sce.muraro[,!qc$discard]
```


``` r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, x="donor", y="sum", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, x="donor", y="detected", colour_by="discard") +
        scale_y_log10() + ggtitle("Detected features"),
    plotColData(unfiltered, x="donor", y="altexps_ERCC_percent",
        colour_by="discard") + ggtitle("ERCC percent"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-qc-dist-1.png" alt="Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-muraro-qc-dist)Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>

We have a look at the causes of removal:


``` r
colSums(as.matrix(qc))
```

```
##              low_lib_size            low_n_features high_altexps_ERCC_percent 
##                       663                       700                       738 
##                   discard 
##                       773
```

## Normalization


``` r
library(scran)
set.seed(1000)
clusters <- quickCluster(sce.muraro)
sce.muraro <- computeSumFactors(sce.muraro, clusters=clusters)
sce.muraro <- logNormCounts(sce.muraro)
```


``` r
summary(sizeFactors(sce.muraro))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##  0.0878  0.5411  0.8208  1.0000  1.2108 13.9869
```


``` r
plot(librarySizeFactors(sce.muraro), sizeFactors(sce.muraro), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset." width="672" />
<p class="caption">(\#fig:unref-muraro-norm)Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset.</p>
</div>

## Variance modelling

We block on a combined plate and donor factor.


``` r
block <- paste0(sce.muraro$plate, "_", sce.muraro$donor)
dec.muraro <- modelGeneVarWithSpikes(sce.muraro, "ERCC", block=block)
top.muraro <- getTopHVGs(dec.muraro, prop=0.1)
```


``` r
par(mfrow=c(8,4))
blocked.stats <- dec.muraro$per.block
for (i in colnames(blocked.stats)) {
    current <- blocked.stats[[i]]
    plot(current$mean, current$total, main=i, pch=16, cex=0.5,
        xlab="Mean of log-expression", ylab="Variance of log-expression")
    curfit <- metadata(current)
    points(curfit$mean, curfit$var, col="red", pch=16)
    curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-variance-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor." width="672" />
<p class="caption">(\#fig:unref-muraro-variance)Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor.</p>
</div>

## Data integration


``` r
library(batchelor)
set.seed(1001010)
merged.muraro <- fastMNN(sce.muraro, subset.row=top.muraro, 
    batch=sce.muraro$donor)
```

We use the proportion of variance lost as a diagnostic measure:


``` r
metadata(merged.muraro)$merge.info$lost.var
```

```
##           D28      D29      D30     D31
## [1,] 0.060847 0.024121 0.000000 0.00000
## [2,] 0.002646 0.003018 0.062421 0.00000
## [3,] 0.003449 0.002641 0.002598 0.08162
```

## Dimensionality reduction


``` r
set.seed(100111)
merged.muraro <- runTSNE(merged.muraro, dimred="corrected")
```

## Clustering


``` r
snn.gr <- buildSNNGraph(merged.muraro, use.dimred="corrected")
colLabels(merged.muraro) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


``` r
tab <- table(Cluster=colLabels(merged.muraro), CellType=sce.muraro$label)
library(pheatmap)
pheatmap(log10(tab+10), color=viridis::viridis(100))
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-seger-heat-1.png" alt="Heatmap of the frequency of cells from each cell type label in each cluster." width="672" />
<p class="caption">(\#fig:unref-seger-heat)Heatmap of the frequency of cells from each cell type label in each cluster.</p>
</div>


``` r
table(Cluster=colLabels(merged.muraro), Donor=merged.muraro$batch)
```

```
##        Donor
## Cluster D28 D29 D30 D31
##      1  104   6  57 112
##      2   59  21  77  97
##      3   12  75  64  43
##      4   28 149 126 120
##      5   87 261 277 214
##      6   21   7  54  26
##      7    1   6   6  37
##      8    6   6   5   2
##      9   11  68   5  30
##      10   4   2   5   8
```


``` r
gridExtra::grid.arrange(
    plotTSNE(merged.muraro, colour_by="label"),
    plotTSNE(merged.muraro, colour_by="batch"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-tsne-1.png" alt="Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right)." width="672" />
<p class="caption">(\#fig:unref-muraro-tsne)Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right).</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.5.0 (2025-04-11)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 24.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.22-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.12.0  LAPACK version 3.12.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] pheatmap_1.0.12             batchelor_1.25.0           
 [3] scran_1.37.0                scater_1.37.0              
 [5] ggplot2_3.5.2               scuttle_1.19.0             
 [7] ensembldb_2.33.0            AnnotationFilter_1.33.0    
 [9] GenomicFeatures_1.61.0      AnnotationDbi_1.71.0       
[11] AnnotationHub_3.99.0        BiocFileCache_2.99.0       
[13] dbplyr_2.5.0                scRNAseq_2.23.0            
[15] SingleCellExperiment_1.31.0 SummarizedExperiment_1.39.0
[17] Biobase_2.69.0              GenomicRanges_1.61.0       
[19] GenomeInfoDb_1.45.0         IRanges_2.43.0             
[21] S4Vectors_0.47.0            BiocGenerics_0.55.0        
[23] generics_0.1.3              MatrixGenerics_1.21.0      
[25] matrixStats_1.5.0           BiocStyle_2.37.0           
[27] rebook_1.19.0              

loaded via a namespace (and not attached):
  [1] RColorBrewer_1.1-3        jsonlite_2.0.0           
  [3] CodeDepends_0.6.6         magrittr_2.0.3           
  [5] ggbeeswarm_0.7.2          gypsum_1.5.0             
  [7] farver_2.1.2              rmarkdown_2.29           
  [9] BiocIO_1.19.0             vctrs_0.6.5              
 [11] DelayedMatrixStats_1.31.0 memoise_2.0.1            
 [13] Rsamtools_2.25.0          RCurl_1.98-1.17          
 [15] htmltools_0.5.8.1         S4Arrays_1.9.0           
 [17] curl_6.2.2                BiocNeighbors_2.3.0      
 [19] Rhdf5lib_1.31.0           SparseArray_1.9.0        
 [21] rhdf5_2.53.0              sass_0.4.10              
 [23] alabaster.base_1.9.0      bslib_0.9.0              
 [25] alabaster.sce_1.9.0       httr2_1.1.2              
 [27] cachem_1.1.0              ResidualMatrix_1.19.0    
 [29] GenomicAlignments_1.45.0  igraph_2.1.4             
 [31] lifecycle_1.0.4           pkgconfig_2.0.3          
 [33] rsvd_1.0.5                Matrix_1.7-3             
 [35] R6_2.6.1                  fastmap_1.2.0            
 [37] GenomeInfoDbData_1.2.14   digest_0.6.37            
 [39] colorspace_2.1-1          dqrng_0.4.1              
 [41] irlba_2.3.5.1             ExperimentHub_2.99.0     
 [43] RSQLite_2.3.9             beachmat_2.25.0          
 [45] labeling_0.4.3            filelock_1.0.3           
 [47] httr_1.4.7                abind_1.4-8              
 [49] compiler_4.5.0            bit64_4.6.0-1            
 [51] withr_3.0.2               BiocParallel_1.43.0      
 [53] viridis_0.6.5             DBI_1.2.3                
 [55] HDF5Array_1.37.0          alabaster.ranges_1.9.0   
 [57] alabaster.schemas_1.9.0   rappdirs_0.3.3           
 [59] DelayedArray_0.35.1       bluster_1.19.0           
 [61] rjson_0.2.23              tools_4.5.0              
 [63] vipor_0.4.7               beeswarm_0.4.0           
 [65] glue_1.8.0                h5mread_1.1.0            
 [67] restfulr_0.0.15           rhdf5filters_1.21.0      
 [69] grid_4.5.0                Rtsne_0.17               
 [71] cluster_2.1.8.1           gtable_0.3.6             
 [73] metapod_1.17.0            BiocSingular_1.25.0      
 [75] ScaledMatrix_1.17.0       XVector_0.49.0           
 [77] ggrepel_0.9.6             BiocVersion_3.22.0       
 [79] pillar_1.10.2             limma_3.65.0             
 [81] dplyr_1.1.4               lattice_0.22-7           
 [83] rtracklayer_1.69.0        bit_4.6.0                
 [85] tidyselect_1.2.1          locfit_1.5-9.12          
 [87] Biostrings_2.77.0         knitr_1.50               
 [89] gridExtra_2.3             bookdown_0.43            
 [91] ProtGenerics_1.41.0       edgeR_4.7.0              
 [93] xfun_0.52                 statmod_1.5.0            
 [95] UCSC.utils_1.5.0          lazyeval_0.2.2           
 [97] yaml_2.3.10               evaluate_1.0.3           
 [99] codetools_0.2-20          tibble_3.2.1             
[101] alabaster.matrix_1.9.0    BiocManager_1.30.25      
[103] graph_1.87.0              cli_3.6.4                
[105] munsell_0.5.1             jquerylib_0.1.4          
[107] Rcpp_1.0.14               dir.expiry_1.17.0        
[109] png_0.1-8                 XML_3.99-0.18            
[111] parallel_4.5.0            blob_1.2.4               
[113] sparseMatrixStats_1.21.0  bitops_1.0-9             
[115] viridisLite_0.4.2         alabaster.se_1.9.0       
[117] scales_1.3.0              purrr_1.0.4              
[119] crayon_1.5.3              rlang_1.1.6              
[121] cowplot_1.1.3             KEGGREST_1.49.0          
```
</div>
